summaryrefslogtreecommitdiff
path: root/src/test
diff options
context:
space:
mode:
authorAlexander Færøy <ahf@torproject.org>2021-11-08 14:12:22 +0000
committerAlexander Færøy <ahf@torproject.org>2021-11-08 14:12:22 +0000
commitfe52c876522b74167f6bd288270d738083461b6b (patch)
tree68c201777a006557b00ff369a98928d044c5dad2 /src/test
parent32c45a8f94d855ed0eaadd652b9bb48c12bf8e1d (diff)
parent94d82baeecb31bdbba76403235f66aad8b6b7eb3 (diff)
downloadtor-fe52c876522b74167f6bd288270d738083461b6b.tar.gz
tor-fe52c876522b74167f6bd288270d738083461b6b.zip
Merge remote-tracking branch 'tor-gitlab/mr/480' into main
Diffstat (limited to 'src/test')
-rw-r--r--src/test/test_sandbox.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/test/test_sandbox.c b/src/test/test_sandbox.c
index e5064c58ec..7ec08a3546 100644
--- a/src/test/test_sandbox.c
+++ b/src/test/test_sandbox.c
@@ -331,13 +331,14 @@ struct testcase_t sandbox_tests[] = {
SANDBOX_TEST_IN_SANDBOX(rename_filename),
/* Currently the sandbox is unable to filter stat() calls on systems where
* glibc implements this function using the legacy "stat" system call, or where
* glibc version 2.33 or later is in use and the newer "newfstatat" syscall is
* available.
*
* Skip testing sandbox_cfg_allow_stat_filename() if it seems the likely the
* function will have no effect and the test will therefore not succeed. */
-#if !defined(__NR_newfstatat) && (!defined(__NR_stat) || defined(__NR_stat64))
+#if !defined(__NR_stat) && !defined(__NR_stat64) && !defined(__NR_newfstatat) \
+ && !(defined(__i386__) && defined(__NR_statx))
SANDBOX_TEST_IN_SANDBOX(stat_filename),
#else
SANDBOX_TEST_SKIPPED(stat_filename),
@@ -331,13 +331,14 @@ struct testcase_t sandbox_tests[] = {
SANDBOX_TEST_IN_SANDBOX(rename_filename),
/* Currently the sandbox is unable to filter stat() calls on systems where
- * glibc implements this function using the legacy "stat" system call, or where
- * glibc version 2.33 or later is in use and the newer "newfstatat" syscall is
- * available.
+ * glibc implements this function using either of the legacy "stat" or "stat64"
+ * system calls, or (in glibc version 2.33 and later) either of the newer
+ * "newfstatat" or "statx" syscalls.
*
* Skip testing sandbox_cfg_allow_stat_filename() if it seems the likely the